@@ -1,6 +1,11 @@
 """Top-level package for PyDaymet."""
 from importlib.metadata import PackageNotFoundError, version
 
+if int(version("shapely").split(".")[0]) > 1:
+    import os
+
+    os.environ["USE_PYGEOS"] = "0"
+
 from .core import Daymet
 from .exceptions import (
     InputRangeError,
